# Slot: alias


the name used for a slot in the context of its owning class.  If present, this is used instead of the actual slot name.

URI: [http://w3id.org/biolink/biolinkml/meta/alias](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [String](String.md)
## Inheritance

## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
